Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2766)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/tags/CheckTag.java	(revision 2783)
@@ -31,4 +31,7 @@
 import javax.servlet.jsp.tagext.TagSupport;
 
+/*import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;*/
+
 import net.fckeditor.handlers.LocalizedMessages;
 import net.fckeditor.handlers.RequestCycleHandler;
@@ -44,12 +47,20 @@
  */
 public class CheckTag extends TagSupport {
+	
+	/*private static final Logger logger = LoggerFactory
+			.getLogger(CheckTag.class);*/
 
 	private static final long serialVersionUID = -6834095891675681686L;
 
 	private static final String FILE_UPLOAD = "FileUpload";
+	@Deprecated
 	private static final String FILE_BROWSING = "FileBrowsing";
+	private static final String GET_RESOURCES = "GetResources";
+	@Deprecated
 	private static final String FOLDER_CREATION = "FolderCreation";
+	private static final String CREATE_FOLDER = "CreateFolder";
 	private static final String COMPATIBLE_BROWSER = "CompatibleBrowser";
-	private static Set<String> commands = new HashSet<String>(4);
+	
+	private static Set<String> commands = new HashSet<String>(6);
 
 	static {
@@ -58,4 +69,6 @@
 		commands.add(FOLDER_CREATION);
 		commands.add(COMPATIBLE_BROWSER);
+		commands.add(GET_RESOURCES);
+		commands.add(CREATE_FOLDER);
 	}
 
@@ -93,23 +106,25 @@
 		}
 
-		if (command.equals(FILE_BROWSING)) {
+		if (command.equals(FILE_BROWSING) || command.equals(GET_RESOURCES)) {
+			//logger.warn("The usage of the FILE_BROWSING command is deprecated");
 			if (RequestCycleHandler.isEnabledForFileBrowsing(request))
-				response = lm.getFileBrowsingEnabled();
+				response = lm.getGetResourcesEnabled();
 			else
-				response = lm.getFileBrowsingDisabled();
+				response = lm.getGetResourcesDisabled();
 		}
 
-		if (command.equals(FOLDER_CREATION)) {
+		if (command.equals(FOLDER_CREATION) || command.equals(CREATE_FOLDER)) {
+			//logger.warn("The usage of the FOLDER_CREATION command is deprecated");
 			if (RequestCycleHandler.isEnabledForFolderCreation(request))
-				response = lm.getFolderCreationEnabled();
+				response = lm.getCreateFolderEnabled();
 			else
-				response = lm.getFolderCreationDisabled();
+				response = lm.getCreateFolderDisabled();
 		}
 
 		if (command.equals(COMPATIBLE_BROWSER)) {
 			if (Compatibility.isCompatibleBrowser(request))
-				response = lm.getCompatibleBrowser();
+				response = lm.getCompatibleBrowserYes();
 			else
-				response = lm.getNotCompatibleBrowser();
+				response = lm.getCompatibleBrowserNo();
 		}
 
Index: FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/response/UploadResponseTest.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/response/UploadResponseTest.java	(revision 2766)
+++ FCKeditor.Java/trunk/java-core/src/test/java/net/fckeditor/response/UploadResponseTest.java	(revision 2783)
@@ -31,5 +31,5 @@
 	public void onlyErrorNumber() throws Exception {
 		UploadResponse actual = new UploadResponse(
-				UploadResponse.SC_INVALID_EXTENSION);
+				UploadResponse.EN_INVALID_FILE_TYPE_ERROR);
 		String expected = new String("<script type=\"text/javascript\">\n"
 				+ "(function(){var d=document.domain;while (true){try{var A=window.parent.document.domain;break;}catch(e) {};d=d.replace(/.*?(?:\\.|$)/,'');if (d.length==0) break;try{document.domain=d;}catch (e){break;}}})();\n"
@@ -40,5 +40,5 @@
 	@Test
 	public void fourArguments() throws Exception {
-		UploadResponse actual = new UploadResponse(UploadResponse.SC_OK,"/fckeditor-java/userfiles/image/fredck.jpg");
+		UploadResponse actual = new UploadResponse(UploadResponse.EN_OK,"/fckeditor-java/userfiles/image/fredck.jpg");
 		String expected = new String("<script type=\"text/javascript\">\n"
 				+ "(function(){var d=document.domain;while (true){try{var A=window.parent.document.domain;break;}catch(e) {};d=d.replace(/.*?(?:\\.|$)/,'');if (d.length==0) break;try{document.domain=d;}catch (e){break;}}})();\n"
@@ -49,5 +49,5 @@
 	@Test
 	public void renamedFile() throws Exception {
-		UploadResponse actual = new UploadResponse(UploadResponse.SC_RENAMED,"/fckeditor-java/userfiles/image/hacked_php.txt","hacked_php.txt");
+		UploadResponse actual = new UploadResponse(UploadResponse.EN_FILE_RENAMED_WARNING,"/fckeditor-java/userfiles/image/hacked_php.txt","hacked_php.txt");
 		String expected = new String("<script type=\"text/javascript\">\n"
 				+ "(function(){var d=document.domain;while (true){try{var A=window.parent.document.domain;break;}catch(e) {};d=d.replace(/.*?(?:\\.|$)/,'');if (d.length==0) break;try{document.domain=d;}catch (e){break;}}})();\n"
@@ -58,5 +58,5 @@
 	@Test
 	public void customMessage() throws Exception {
-		UploadResponse actual = new UploadResponse(UploadResponse.SC_ERROR);
+		UploadResponse actual = new UploadResponse(UploadResponse.EN_CUSTOM_ERROR);
 		actual.setCustomMessage("some error");
 		String expected = new String("<script type=\"text/javascript\">\n"
@@ -69,5 +69,5 @@
 	@Test
 	public void nullArguments() throws Exception {
-		UploadResponse actual = new UploadResponse(UploadResponse.SC_ERROR,null,null,null);
+		UploadResponse actual = new UploadResponse(UploadResponse.EN_CUSTOM_ERROR,null,null,null);
 		String expected = new String("<script type=\"text/javascript\">\n"
 				+ "(function(){var d=document.domain;while (true){try{var A=window.parent.document.domain;break;}catch(e) {};d=d.replace(/.*?(?:\\.|$)/,'');if (d.length==0) break;try{document.domain=d;}catch (e){break;}}})();\n"
Index: FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp
===================================================================
--- FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp	(revision 2766)
+++ FCKeditor.Java/trunk/java-demo/src/main/webapp/jsp/sample01.jsp	(revision 2783)
@@ -50,7 +50,7 @@
 		<ul>
 			<li><FCK:check command="CompatibleBrowser" /></li>
-			<li><FCK:check command="FileBrowsing" /></li>
+			<li><FCK:check command="GetResources" /></li>
 			<li><FCK:check command="FileUpload" /></li>
-			<li><FCK:check command="FolderCreation" /></li>
+			<li><FCK:check command="CreateFolder" /></li>
 		</ul>
 		<hr />
Index: FCKeditor.Java/trunk/src/site/apt/properties.apt
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/properties.apt	(revision 2766)
+++ FCKeditor.Java/trunk/src/site/apt/properties.apt	(revision 2783)
@@ -161,7 +161,44 @@
 |									|											| implementation|													|
 *-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.compatible_browser.yes	| Your browser is fully compatible			| any string	| Indicates that the browser is fully compatible.	|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.compatible_browser.no		| Your browser is not compatible			| any string	| Indicates that the browser is not compatible.		|
+| message.editor.					| Your browser is fully compatible			| any string	| Indicates that the browser is fully compatible.	|
+| compatibleBrowser.yes				|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.editor.					| Your browser is not compatible			| any string	| Indicates that the browser is not compatible.		|
+| compatibleBrowser.no				|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| Invalid command specified					| any string	| The provided command was invalid/does not exist.	|
+| invalid_command_specified			|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| Invalid resource type specified			| any string	| The provided type was invalid/does not exist.		|
+| invalid_resource_type_specified	|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| Invalid current folder specified			| any string	| The provided current folder was invalid/does		|
+| invalid_current_folder_specified	|											|				| not exist.										|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| You are authorized to browse/list			| any string	| Responds the user can browse/list files			|
+| getResources.enabled				| files and/or folders!						|				| and/or folders.									|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| You are not authorized to browse/list		| any string	| Responds the user cannot browse/list files		|
+| getResources.disabled				| files and/or folders!						|				| and/or folders.									|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| The selected resources could not			| any string	| Responds the user that during fetching the		|
+| getResources.read_error			| be read successfully, please try again!	|				| resources list some error/exception has occured.	|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| You are authorized to create folders!		| any string	| Responds the user can create folders.				|
+| createFolder.enabled				|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| You are not authorized to create folders!	| any string	| Responds the user cannot create folders.			|
+| createFolder.disabled				|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| Invalid new folder name specified			| any string	| The provided new folder name was invalid.			|
+| createFolder.invalid_new_folder_	|											|				|													|
+| name_specified					|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| The specified folder already exists		| any string	| The specified folder already exists on the		|
+| createFolder.folder_already_		|											|				| server.											|
+| exists_error						|											|				|													|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| The specified folder could not			| any string	| Responds the user that during creating the		|
+| createFolder.write_error			| be created successfully, please try again!|				| folder some error/exception has occured.			|
 *-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
 | message.connector.fileUpload.		| You are authorized to upload files!		| any string	| Responds the user can upload files.				|
@@ -171,23 +208,14 @@
 | disabled							|											|				|													|
 *-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| You are authorized to browse files!		| any string	| Responds the user can browse files.				|
-| fileBrowsing.enabled				|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| You are not authorized to browse files!	| any string	| Responds the user cannot browse files.			|
-| fileBrowsing.disabled				|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| You are authorized to create folders!		| any string	| Responds the user can create folders.				|
-| folderCreation.enabled			|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| You are not authorized to create folders!	| any string	| Responds the user cannot create folders.			|
-| folderCreation.disabled			|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| Invalid command specified					| any string	| The provided command was invalid/does not exist.	|
-| invalid_command_specified			|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| Invalid resource type specified			| any string	| The provided type was invalid/does not exist.		|
-| invalid_type_specified			|											|				|													|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
-| message.connector.				| Invalid current folder specified			| any string	| The provided current folder was invalid/does		|
-| invalid_current_folder_speficied	|											|				| not exist.										|
-*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.fileUpload.		| Your file was uploaded successfully		| any string	| Warns the user about a successful upload			|
+| file_renamed_warning				| but has been renamed to '\{0\}'.			| \{0\} - new filename| but file has been renamed because another	|
+|									|											|				| file exists with the same name.					|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.fileUpload.		| The uploaded has a wrong file type		| any string	| Warns the user about the uploaded file has		|
+| invalid_file_type_specified		| (extension).								|				| a file type (extension) which does not			|
+|									|											|				| correspond to the resource type's					|
+|									|											|				|  allowed/denied list.								|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
+| message.connector.				| The specified file could not be			| any string	| Responds the user that during file upload			|
+| fileUpload.write_error			| uploaded successfully, please try again!	|				| some error/exception has occured.					|
+*-----------------------------------+-------------------------------------------+---------------+---------------------------------------------------+
Index: FCKeditor.Java/trunk/src/site/apt/upgrade_notes.apt.vm
===================================================================
--- FCKeditor.Java/trunk/src/site/apt/upgrade_notes.apt.vm	(revision 2766)
+++ FCKeditor.Java/trunk/src/site/apt/upgrade_notes.apt.vm	(revision 2783)
@@ -36,4 +36,6 @@
 || Ticket						|| Remark									  ||
 *-------------------------------+----------------------------------------------+
+| -								| The features/commands <<<FolderCreation>>> and <<<FileBrowsing>>> in the {{{java-core/tagreference.html#FCK:check}CheckTag}} have been deprecated. |
+*-------------------------------+----------------------------------------------+
 | {{{${ticketUrl}/2618}2618}}	| So far we have used ImageInfo which was incorporated into our core jar. We have refactored it and removed from our jar. It is now on |
 |								| Maven Central Repo. Maven users do not have to bother but those who don't use Maven please make sure that the ImageInfo jar is on |
Index: FCKeditor.Java/trunk/src/site/fml/faq.fml
===================================================================
--- FCKeditor.Java/trunk/src/site/fml/faq.fml	(revision 2766)
+++ FCKeditor.Java/trunk/src/site/fml/faq.fml	(revision 2783)
@@ -22,5 +22,4 @@
   <part id="general">
     <title>General</title>
-   
     <faq id="context-fullurl">
       <question>
@@ -36,4 +35,22 @@
       </answer>
     </faq>
+  </part>
+  
+  <part id="localization">
+    <title>Localization</title>
+   
+    <faq id="no-localized-messages">
+      <question>
+        I have localized some messages but they don't appear in the alert boxes.
+        Did I something wrong? What can I do about?
+      </question>
+      <answer>
+        Unfortunately the the JavaScript code which responds the error messages
+        is incomplete. It does not cover all error numbers and has static error
+        messages. You can fix this by searching for all files which read the GetResponse
+        or UploadResponse and let the switch clause simply alert your localized
+        message.
+      </answer>
+    </faq>
 
   </part>

Index: FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java
===================================================================
--- FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2766)
+++ FCKeditor.Java/trunk/java-core/src/main/java/net/fckeditor/response/UploadResponse.java	(revision 2783)
@@ -49,23 +49,21 @@
 	private Object[] parameters;
 
-	// Naming scheme according static status codes in
-	// javax.servlet.http.HttpServletResponse
 	/** Error number OK */
-	public static final int SC_OK = 0;
-
-	/** Error number ERROR */
-	public static final int SC_ERROR = 1;
-	
-	/** Error number UNKNOWN ERROR */
-	public static final int SC_UKNOWN = 110;
-
-	/** Error number RENAMED */
-	public static final int SC_RENAMED = 201;
-
-	/** Error number INVALID EXTENSION */
-	public static final int SC_INVALID_EXTENSION = 202;
+	public static final int EN_OK = 0;
+
+	/** Error number CUSTOM ERROR */
+	public static final int EN_CUSTOM_ERROR = 1;
+	
+	/** Error number CUSTOM WARNING */
+	public static final int EN_CUSTOM_WARNING = 101;
+	
+	/** Error number FILE RENAMED WARNING */
+	public static final int EN_FILE_RENAMED_WARNING = 201;
+
+	/** Error number INVALID FILE TYPE */
+	public static final int EN_INVALID_FILE_TYPE_ERROR = 202;
 
 	/** Error number SECURITY ERROR */
-	public static final int SC_SECURITY_ERROR = 203;
+	public static final int EN_SECURITY_ERROR = 203;
 
 	/**
@@ -129,34 +127,44 @@
 	}
 	
-	public static UploadResponse getErrorSecurity() {
-		return new UploadResponse(SC_SECURITY_ERROR);
-	}
-	
-	public static UploadResponse getErrorInvalidExtension() {
-		return new UploadResponse(SC_INVALID_EXTENSION);
-	}
-	
-	public static UploadResponse getErrorUnknown() {
-		return new UploadResponse(SC_UKNOWN);
-	}
-	
-	public static UploadResponse getErrorInvalidCommand() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new UploadResponse(SC_ERROR, null, null, lm.getInvalidCommand());
-	}
-	
-	public static UploadResponse getErrorInvalidType() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new UploadResponse(SC_ERROR, null, null, lm.getInvalidType());
-	}
-	
-	public static UploadResponse getErrorInvalidCurrentFolder() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new UploadResponse(SC_ERROR, null, null, lm.getInvalidCurrentFolder());
-	}
-
-	public static UploadResponse getErrorFileUploadDisabled() {
-		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
-		return new UploadResponse(SC_ERROR, null, null, lm.getFileUploadDisabled());
+	
+	public static UploadResponse getOK(String fileUrl) {
+		return new UploadResponse(EN_OK, fileUrl);
+	}
+	
+	public static UploadResponse getFileRenamedWarning(String fileUrl, String newFileName) {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_FILE_RENAMED_WARNING, fileUrl,
+				newFileName, lm.getFileRenamedWarning(newFileName));
+	}
+	
+	public static UploadResponse getInvalidFileTypeError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_INVALID_FILE_TYPE_ERROR, lm.getInvalidFileTypeSpecified());
+	}
+	
+	public static UploadResponse getInvalidCommandError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_CUSTOM_ERROR, null, null, lm.getInvalidCommandSpecified());
+	}
+	
+	public static UploadResponse getInvalidResourceTypeError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_CUSTOM_ERROR, null, null, lm.getInvalidResouceTypeSpecified());
+	}
+	
+	public static UploadResponse getInvalidCurrentFolderError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_CUSTOM_ERROR, null, null, lm.getInvalidCurrentFolderSpecified());
+	}
+
+	public static UploadResponse getFileUploadDisabledError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_SECURITY_ERROR, null, null, lm.getFileUploadDisabled());
+	}
+	
+	// TODO which EN to respond?
+	public static UploadResponse getFileUploadWriteError() {
+		LocalizedMessages lm = LocalizedMessages.getMessages(ThreadLocalData.getRequest());
+		return new UploadResponse(EN_CUSTOM_ERROR, null, null, lm.getFileUploadWriteError());
 	}
 